<!-- Copyright © SixtyFPS GmbH <info@slint.dev> ; SPDX-License-Identifier: MIT -->
## `AboutSlint`

This element displays a "Made with Slint" badge.

```slint
import { AboutSlint } from "std-widgets.slint";
export component Example inherits Window {
    height: 175px;
    AboutSlint {
    }
}
```
